CoverageSplitter
================

.. currentmodule:: pykeen.triples.splitting

.. autoclass:: CoverageSplitter
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CoverageSplitter.split_absolute_size

   .. rubric:: Methods Documentation

   .. automethod:: split_absolute_size
